@@ -1,8 +1,4 @@
-/* $Id: config.h 1462 2007-12-18 20:49:56Z holger $
- *
- * HoiChess/config.h
- *
- * Copyright (C) 2004, 2005 Holger Ruckdeschel <holger@hoicher.de>
+/* Copyright (C) 2004-2008 Holger Ruckdeschel <holger@hoicher.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,38 +19,19 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
-/* Default size of main hash table */
-#define DEFAULT_HASHSIZE	"32M"
+/* Use assembler code where supported */
+#define USE_ASM
 
-/* Default size of pawn hash table */
-#define DEFAULT_PAWNHASHSIZE	"4M"
-
-/* Default size of evaluation cache */
-#define DEFAULT_EVALCACHESIZE	"4M"
-
-/* Default location of opening book */
-#define DEFAULT_BOOK		"book.dat"
+/* Enable thread support (pondering and analysis) */
+#if defined(HAVE_PTHREAD) || defined(WIN32)
+# define USE_THREAD
+#endif
 
 /* Use a single board in search tree, in connection with Board::unmake_move().
  * Otherwise, the board will be copied from node to node each time a move is
  * made. */
 //#define USE_UNMAKE_MOVE
 
-/* Use internal iterative deepening */
-#define USE_IID
-
-/* Use principal variation search */
-#define USE_PVS
-
-/* Use history table */
-#define USE_HISTORY
-
-/* Use killer heuristic */
-#define USE_KILLER
-
-/* Use null-move pruning */
-#define USE_NULLMOVE
-
 /* Use futility pruning */
 #define USE_FUTILITYPRUNING
 
@@ -64,13 +41,6 @@
 /* Use razoring */
 //#define USE_RAZORING
 
-/* Use evaluation cache */
-#define USE_EVALCACHE
-
-/* Search extensions */
-#define EXTEND_IN_CHECK
-#define EXTEND_RECAPTURE
-
 /* Maximum depth for full-width search */
 #define MAXDEPTH		900
 
@@ -83,8 +53,4 @@
 /* Collect statistics, e.g. hash table hits, cutoffs during search, etc. */
 #define COLLECT_STATISTICS
 
-/* Collect statistics about maximum number of moves stored in a movelist
- * (expensive!) */
-//#define STATS_MOVELIST
-
 #endif // CONFIG_H
